@@ -23,16 +23,16 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class CloseDeployOrderRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'CloseDeployOrder','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'CloseDeployOrder')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DeployOrderId(self):
+	def get_DeployOrderId(self): # Long
 		return self.get_query_params().get('DeployOrderId')
 
-	def set_DeployOrderId(self,DeployOrderId):
-		self.add_query_param('DeployOrderId',DeployOrderId)
\ No newline at end of file
+	def set_DeployOrderId(self, DeployOrderId):  # Long
+		self.add_query_param('DeployOrderId', DeployOrderId)
