@@ -23,16 +23,16 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class DeleteAppResourceAllocRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DeleteAppResourceAlloc','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DeleteAppResourceAlloc')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppEnvId(self):
+	def get_AppEnvId(self): # Long
 		return self.get_query_params().get('AppEnvId')
 
-	def set_AppEnvId(self,AppEnvId):
-		self.add_query_param('AppEnvId',AppEnvId)
\ No newline at end of file
+	def set_AppEnvId(self, AppEnvId):  # Long
+		self.add_query_param('AppEnvId', AppEnvId)
