@@ -23,16 +23,16 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class DeleteDeployConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DeleteDeployConfig','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DeleteDeployConfig')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SchemaId(self):
+	def get_SchemaId(self): # Long
 		return self.get_query_params().get('SchemaId')
 
-	def set_SchemaId(self,SchemaId):
-		self.add_query_param('SchemaId',SchemaId)
\ No newline at end of file
+	def set_SchemaId(self, SchemaId):  # Long
+		self.add_query_param('SchemaId', SchemaId)
