@@ -23,16 +23,16 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class DescribeAppDetailRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DescribeAppDetail','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DescribeAppDetail')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppId(self):
+	def get_AppId(self): # Long
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
\ No newline at end of file
+	def set_AppId(self, AppId):  # Long
+		self.add_query_param('AppId', AppId)
