@@ -23,22 +23,21 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class DescribeAppEnvironmentDetailRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DescribeAppEnvironmentDetail','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DescribeAppEnvironmentDetail')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppId(self):
+	def get_AppId(self): # Long
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
-
-	def get_EnvId(self):
+	def set_AppId(self, AppId):  # Long
+		self.add_query_param('AppId', AppId)
+	def get_EnvId(self): # Long
 		return self.get_query_params().get('EnvId')
 
-	def set_EnvId(self,EnvId):
-		self.add_query_param('EnvId',EnvId)
\ No newline at end of file
+	def set_EnvId(self, EnvId):  # Long
+		self.add_query_param('EnvId', EnvId)
