@@ -23,16 +23,16 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class DescribeServiceDetailRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DescribeServiceDetail','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'DescribeServiceDetail')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ServiceId(self):
+	def get_ServiceId(self): # Long
 		return self.get_query_params().get('ServiceId')
 
-	def set_ServiceId(self,ServiceId):
-		self.add_query_param('ServiceId',ServiceId)
\ No newline at end of file
+	def set_ServiceId(self, ServiceId):  # Long
+		self.add_query_param('ServiceId', ServiceId)
