@@ -23,28 +23,26 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class GetInstTransInfoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'GetInstTransInfo','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'GetInstTransInfo')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_aliyunUid(self):
+	def get_aliyunUid(self): # String
 		return self.get_body_params().get('aliyunUid')
 
-	def set_aliyunUid(self,aliyunUid):
+	def set_aliyunUid(self, aliyunUid):  # String
 		self.add_body_params('aliyunUid', aliyunUid)
-
-	def get_aliyunEquipId(self):
+	def get_aliyunEquipId(self): # String
 		return self.get_body_params().get('aliyunEquipId')
 
-	def set_aliyunEquipId(self,aliyunEquipId):
+	def set_aliyunEquipId(self, aliyunEquipId):  # String
 		self.add_body_params('aliyunEquipId', aliyunEquipId)
-
-	def get_aliyunCommodityCode(self):
+	def get_aliyunCommodityCode(self): # String
 		return self.get_body_params().get('aliyunCommodityCode')
 
-	def set_aliyunCommodityCode(self,aliyunCommodityCode):
-		self.add_body_params('aliyunCommodityCode', aliyunCommodityCode)
\ No newline at end of file
+	def set_aliyunCommodityCode(self, aliyunCommodityCode):  # String
+		self.add_body_params('aliyunCommodityCode', aliyunCommodityCode)
