@@ -23,40 +23,36 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class ListAppEnvironmentRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListAppEnvironment','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListAppEnvironment')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EnvName(self):
+	def get_EnvName(self): # String
 		return self.get_query_params().get('EnvName')
 
-	def set_EnvName(self,EnvName):
-		self.add_query_param('EnvName',EnvName)
-
-	def get_AppId(self):
+	def set_EnvName(self, EnvName):  # String
+		self.add_query_param('EnvName', EnvName)
+	def get_AppId(self): # Long
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
-
-	def get_EnvType(self):
+	def set_AppId(self, AppId):  # Long
+		self.add_query_param('AppId', AppId)
+	def get_EnvType(self): # Integer
 		return self.get_query_params().get('EnvType')
 
-	def set_EnvType(self,EnvType):
-		self.add_query_param('EnvType',EnvType)
-
-	def get_PageSize(self):
+	def set_EnvType(self, EnvType):  # Integer
+		self.add_query_param('EnvType', EnvType)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_PageNumber(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
\ No newline at end of file
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
