@@ -23,28 +23,26 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class ListClusterNodeRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListClusterNode','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListClusterNode')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_PageSize(self):
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_PageNum(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
-
-	def get_ClusterInstanceId(self):
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_ClusterInstanceId(self): # String
 		return self.get_query_params().get('ClusterInstanceId')
 
-	def set_ClusterInstanceId(self,ClusterInstanceId):
-		self.add_query_param('ClusterInstanceId',ClusterInstanceId)
\ No newline at end of file
+	def set_ClusterInstanceId(self, ClusterInstanceId):  # String
+		self.add_query_param('ClusterInstanceId', ClusterInstanceId)
