@@ -23,34 +23,31 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class ListClusterRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListCluster','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListCluster')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BusinessCode(self):
+	def get_BusinessCode(self): # String
 		return self.get_query_params().get('BusinessCode')
 
-	def set_BusinessCode(self,BusinessCode):
-		self.add_query_param('BusinessCode',BusinessCode)
-
-	def get_EnvType(self):
+	def set_BusinessCode(self, BusinessCode):  # String
+		self.add_query_param('BusinessCode', BusinessCode)
+	def get_EnvType(self): # String
 		return self.get_query_params().get('EnvType')
 
-	def set_EnvType(self,EnvType):
-		self.add_query_param('EnvType',EnvType)
-
-	def get_PageSize(self):
+	def set_EnvType(self, EnvType):  # String
+		self.add_query_param('EnvType', EnvType)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_PageNum(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
\ No newline at end of file
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
