@@ -23,46 +23,41 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class ListNodeLabelBindingsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListNodeLabelBindings','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListNodeLabelBindings')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_InstanceId(self):
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_LabelKey(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_LabelKey(self): # String
 		return self.get_query_params().get('LabelKey')
 
-	def set_LabelKey(self,LabelKey):
-		self.add_query_param('LabelKey',LabelKey)
-
-	def get_LabelValue(self):
+	def set_LabelKey(self, LabelKey):  # String
+		self.add_query_param('LabelKey', LabelKey)
+	def get_LabelValue(self): # String
 		return self.get_query_params().get('LabelValue')
 
-	def set_LabelValue(self,LabelValue):
-		self.add_query_param('LabelValue',LabelValue)
-
-	def get_PageSize(self):
+	def set_LabelValue(self, LabelValue):  # String
+		self.add_query_param('LabelValue', LabelValue)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_ClusterId(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_PageNumber(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
\ No newline at end of file
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
