@@ -23,34 +23,31 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class ListNodeLabelsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListNodeLabels','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ListNodeLabels')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LabelKey(self):
+	def get_LabelKey(self): # String
 		return self.get_query_params().get('LabelKey')
 
-	def set_LabelKey(self,LabelKey):
-		self.add_query_param('LabelKey',LabelKey)
-
-	def get_PageSize(self):
+	def set_LabelKey(self, LabelKey):  # String
+		self.add_query_param('LabelKey', LabelKey)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_ClusterId(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_PageNumber(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
\ No newline at end of file
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
