@@ -23,16 +23,16 @@ from aliyunsdkretailcloud.endpoint import endpoint_data
 class ResourceStatusNotifyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ResourceStatusNotify','retailcloud')
+		RpcRequest.__init__(self, 'retailcloud', '2018-03-13', 'ResourceStatusNotify')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_data(self):
+	def get_data(self): # String
 		return self.get_body_params().get('data')
 
-	def set_data(self,data):
-		self.add_body_params('data', data)
\ No newline at end of file
+	def set_data(self, data):  # String
+		self.add_body_params('data', data)
